@@ -25,7 +25,7 @@ def logp(x: np.ndarray) -> float:
     """
     if global_progressbar:
         bar.update(1)
-    if np.all((global_bounds[0] < x) & (x < global_bounds[1])):
+    if np.all((global_bounds[:, 0] < x) & (x < global_bounds[:, 1])):
         return 0
     else:
         return -np.inf
@@ -42,7 +42,7 @@ class EmceeCorner():
         """Make bounds, logl, and logp for ptemcee.
 
         Args:
-            bounds (np.ndarray): Bounds for ptemcee in the shape of (2, dim).
+            bounds (np.ndarray): Bounds for ptemcee in the shape of (dim, 2).
             logl (function, optional): Log likelihood for ptemcee. Defaults to None.
             model (function, optional): Model function to make a log likelihood function. Defaults to None.
             xdata (np.ndarray, optional): Input for the model function. Defaults to None.
@@ -52,13 +52,17 @@ class EmceeCorner():
             percent (list, optional): The lower and upper percnetiles to be calculated. Defaults to [16, 84].
         """
         global global_bounds, global_progressbar
-        global_bounds = np.array(bounds) if len(bounds) < 3 else np.transpose(bounds)
+        if len(bounds[0]) > 3:
+            global_bounds = np.transpose(bounds)
+            print('bounds has been transposed because its shape is (2, dim).')
+        else:
+            global_bounds = np.array(bounds)
         global_progressbar = progressbar
         if logl is None and not (None in [model, xdata, ydata]):
             def logl(x: np.ndarray) -> float:
                 return np.sum((ydata - model(xdata, *x))**2 / sigma**2) / (-2)
         self.bounds = global_bounds
-        self.dim = len(self.bounds[0])
+        self.dim = len(self.bounds)
         self.logl = logl
         self.logp = logp
         self.percent = percent
@@ -99,7 +103,8 @@ class EmceeCorner():
             i += 1
             if pos0 is None:
                 pos0 = np.random.rand(ntemps, nwalkers, self.dim) \
-                       * (self.bounds[1] - self.bounds[0]) + self.bounds[0]
+                       * (self.bounds[:, 1] - self.bounds[:, 0]) \
+                       + self.bounds[:, 0]
                 if not pt:
                     pos0 = pos0[0]
             if pt:
@@ -112,7 +117,7 @@ class EmceeCorner():
                 else:
                     sampler = ptemcee.Sampler(**pars)
                     sampler.run_mcmc(pos0, nsteps)
-                samples = sampler.chain[0, :, nburnin:, :]  # temperature, walker, step, dim
+                samples = sampler.chain[0, :, nburnin:, :]  # temperatures, walkers, steps, dim
             else:
                 if ncores > 1:
                     print('Use logl as log_prob_fn to avoid function-in-function.')
@@ -130,7 +135,7 @@ class EmceeCorner():
                 else:
                     sampler = emcee.EnsembleSampler(**pars)
                     sampler.run_mcmc(pos0, nsteps)
-                samples = sampler.chain[:, nburnin:, :]  # walker, step, dim
+                samples = sampler.chain[:, nburnin:, :]  # walkers, steps, dim
             if grcheck:
                 # Gelman-Rubin statistics #
                 B = np.std(np.mean(samples, axis=1), axis=0)
@@ -165,7 +170,7 @@ class EmceeCorner():
             print('')
 
     def plotcorner(self, show: bool = False,
-                   savefig: str | None = None, labels: list[float] | None = None,
+                   savefig: str | None = None, labels: list[str] | None = None,
                    cornerrange: list[float] | None = None) -> None:
         """Make the corner plot from self.samples.
 
@@ -178,7 +183,7 @@ class EmceeCorner():
         if labels is None:
             labels = [f'Par {i:d}' for i in range(self.dim)]
         if cornerrange is None:
-            cornerrange = np.transpose(self.bounds)
+            cornerrange = self.bounds
         corner.corner(np.reshape(self.samples, (-1, self.dim)), truths=self.popt,
                       quantiles=[self.percent[0] / 100, 0.5, self.percent[1] / 100],
                       show_titles=True, labels=labels, range=cornerrange)
@@ -190,7 +195,7 @@ class EmceeCorner():
 
     def plotchain(self, show: bool = False, savefig: str = None,
                   labels: list = None, ylim: list = None):
-        """Plot parameters as a function of steps using self.samples.
+        """Plot parameters as a function of steps using self.samples. This method plots nine lines: percent[0], 50%, percent[1] percentiles (over the steps by 1% binning) of percent[0], 50%, percent[1] percentiles (over the walkers).
 
         Args:
             show (bool, optional): Whether to show the chain plot. Defaults to False.
@@ -201,18 +206,18 @@ class EmceeCorner():
         if labels is None:
             labels = [f'Par {i:d}' for i in range(self.dim)]
         if ylim is None:
-            ylim = np.transpose(self.bounds)
+            ylim = self.bounds
         fig = plt.figure(figsize=(4, 2 * self.dim))
         x = np.arange(np.shape(self.samples)[1])
         naverage = max(1, len(x) // 100)
         nend = len(x) - len(x) % 100 if naverage > 1 else len(x)
         x = x[:nend:naverage]
         for i in range(self.dim):
-            y = self.samples[:, :, i]
+            y = self.samples[:, :, i]  # walkers, steps, dim
             plist = [self.percent[0], 50, self.percent[1]]
-            y = [np.percentile(y, p, axis=0) for p in plist]
+            y = [np.percentile(y, p, axis=0) for p in plist]  # percent over the walkers, steps
             y = [[np.percentile(np.reshape(yy[:nend], (naverage, -1)), p, axis=0)
-                  for p in plist] for yy in y]
+                  for p in plist] for yy in y]  # percent over the walkers, percent over the steps
             ax = fig.add_subplot(self.dim, 1, i + 1)
             for yy, l, c in zip(y, [1, 2, 1], ['c', 'b', 'c']):
                 for yyy, w in zip(yy, [0.25, 1, 0.25]):
@@ -244,7 +249,7 @@ class EmceeCorner():
         if type(log) is bool:
             log = [log] * self.dim
         pargrid = []
-        for a, b, c, d in zip(*global_bounds, ngrid, log):
+        for a, b, c, d in zip(self.bounds[:, 0], self.bounds[:, 1], ngrid, log):
             pargrid.append(np.geomspace(a, b, c) if d else np.linspace(a, b, c))
         p = np.exp(self.logl(np.meshgrid(*pargrid[::-1], indexing='ij')[::-1]))
         p[p < pcut] = 0
@@ -260,8 +265,6 @@ class EmceeCorner():
         axlist = [tuple(np.delete(adim, i)) for i in adim[::-1]]  # adim[::-1] is becuase the 0th parameter is the innermost axis.
         p1d = [np.sum(p * vol, axis=a) / np.sum(vol, axis=a) for a in axlist]
         evidence = np.sum(p * vol) / np.sum(vol)
-        p1dcum = [np.cumsum(q * w) / np.transpose([np.sum(q * w)])
-                  for q, w in zip(p1d, dpar)]
         if np.all(p == 0):
             print('All posterior is below pcut.')
             self.popt = np.full(self.dim, np.nan)
@@ -269,16 +272,17 @@ class EmceeCorner():
             self.pmid = np.full(self.dim, np.nan)
             self.phigh = np.full(self.dim, np.nan)
         else:
-            iopt = np.unravel_index(np.argmax(p), np.shape(p))[::-1]
-            self.popt = [t[i] for t, i in zip(pargrid, iopt)]
+            i_max = np.unravel_index(np.argmax(p), np.shape(p))[::-1]
+            self.popt = np.array([p[i] for p, i in zip(pargrid, i_max)])
 
             def getpercentile(percent: float):
-                idxmin = [np.argmin(np.abs(q - percent)) for q in p1dcum]
-                return np.array([t[i] for t, i in zip(pargrid, idxmin)])
+                a = [np.percentile(g, percent, method='inverted_cdf', weights=p)
+                     for g, p in zip(pargrid, p1d)]
+                return np.array(a)
 
-            self.plow = getpercentile(self.percent[0] / 100)
-            self.pmid = getpercentile(0.5)
-            self.phigh = getpercentile(self.percent[1] / 100)
+            self.plow = getpercentile(self.percent[0])
+            self.pmid = getpercentile(50)
+            self.phigh = getpercentile(self.percent[1])
         self.p = p
         self.p1d = p1d
         self.pargrid = pargrid
@@ -287,7 +291,7 @@ class EmceeCorner():
 
     def plotongrid(self, show: bool = False, savefig: str | None = None,
                    labels: list[str] = None, cornerrange: list[float] = None,
-                   cmap: str = 'binary', levels: list[float] = [0.001, 0.01, 0.1]) -> None:
+                   cmap: str = 'binary', levels: list[float] = [0.011109, 0.135335, 0.606531]) -> None:
         """Make the corner plot from the posterior calculated on a grid.
 
         Args:
@@ -296,13 +300,13 @@ class EmceeCorner():
             labels (list, optional): Labels for the corner plot. Defaults to None.
             cornerrange (list, optional): Range for the corner plot. Defaults to None.
             cmap: (str, optional): cmap for matplotlib.pyplot.plt.pcolormesh(). Defaults to 'binary'.
-            levels: (list, optional): levels for matplotlib.pyplot.plt.contour() relative to the peak. Defaults to [0.001, 0.01, 0.1].
+            levels: (list, optional): levels for matplotlib.pyplot.plt.contour() relative to the peak. Defaults to [exp(-0.5*3^2), exp(-0.5*2^2), exp(-0.5*1^2)].
         """
         adim = np.arange(self.dim)
         if labels is None:
             labels = [f'Par {i:d}' for i in adim]
         if cornerrange is None:
-            cornerrange = np.transpose(self.bounds)
+            cornerrange = self.bounds
         x = self.pargrid
         y = self.p1d
         fig = plt.figure(figsize=(2 * self.dim * 1.2, 2 * self.dim))
@@ -322,7 +326,7 @@ class EmceeCorner():
                     s2 = '_{-' + f'{s2:.2f}' + '}'
                     s0 = s0 + s1 + s2
                     ax[k] = fig.add_subplot(self.dim, self.dim, k + 1)
-                    ax[k].plot(x[i], y[i], 'k-')
+                    ax[k].plot(x[i], y[i], 'k-', drawstyle='steps-mid')
                     ax[k].axvline(self.popt[i])
                     ax[k].axvline(self.plow[i], linestyle='--', color='k')
                     ax[k].axvline(self.pmid[i], linestyle='--', color='k')
@@ -371,7 +375,7 @@ class EmceeCorner():
         """Calculate the Bayesian evidence for a model using dynamic nested sampling through dynesty.
         """
         def prior_transform(u):
-            return self.bounds[0] + (self.bounds[1] - self.bounds[0]) * u
+            return self.bounds[:, 0] + (self.bounds[:, 1] - self.bounds[:, 0]) * u
         dsampler = DNS(loglikelihood=self.logl,
                        prior_transform=prior_transform,
                        ndim=self.dim, **kwargs)
@@ -379,4 +383,5 @@ class EmceeCorner():
         results = dsampler.results
         evidence = np.exp(results.logz[-1])
         error = evidence * results.logzerr[-1]
+        self.evidence = evidence
         return {'evidence': evidence, 'error': error}
