@@ -293,6 +293,26 @@ def kwargs2PlotAxes2D(kw: dict) -> PlotAxes2D:
     return d
 
 
+def kwargs2beamargs(kw: dict) -> dict:
+    """Get arguments for add_beam() from kwargs.
+
+    Args:
+        kw (dict): Parameters to make beam.
+
+    Returns:
+        dict: Arguments for add_beam().
+    """
+    tmp = {}
+    for k in ['show_beam', 'beamcolor', 'beampos']:
+        if k in kw:
+            tmp[k] = kw[k]
+            del kw[k]
+    if 'beam_kwargs' in kw:
+        tmp.update(kw['beam_kwargs'])
+        del kw['beam_kwargs']
+    return tmp
+
+
 class PlotAstroData(AstroFrame):
     """Make a figure from 2D/3D FITS files or 2D/3D arrays.
 
@@ -478,7 +498,7 @@ class PlotAstroData(AstroFrame):
                       angle=angle * self.xdir, **_kw)
                 axnow.add_patch(p)
 
-    def add_beam(self,
+    def add_beam(self, show_beam: bool = True,
                  beam: list[float | None, float | None, float | None] = [None, None, None],
                  beamcolor: str = 'gray',
                  beampos: list[float, float] | None = None,
@@ -486,10 +506,13 @@ class PlotAstroData(AstroFrame):
         """Use add_region(). All the arguments may be a list of each format.
 
         Args:
-            beam (list, optional): [bmaj, bmin, bpa]. Defaults to [None, None, None].
-            beamcolor (str, optional): matplotlib color. Defaults to 'gray'.
-            beampos (list, optional): Relative position. Defaults to None.
+            show_beam (bool, optional): Defaults to True.
+            beam (list, optional): [bmaj, bmin, bpa]. This may be a list of list. Defaults to [None, None, None].
+            beamcolor (str, optional): matplotlib color. This may be a list of str. Defaults to 'gray'.
+            beampos (list, optional): Relative position. This may be a list of list or a list of None. Defaults to None.
         """
+        if not show_beam:
+            return
         include_chan = self.bottomleft if self.channelnumber is None else self.allchan
         patch = 'rectangle' if self.pv else 'ellipse'
         blist = [beam] if np.ndim(beam) == 1 else beam
@@ -648,11 +671,8 @@ class PlotAstroData(AstroFrame):
                   show_cbar: bool = True, cblabel: str | None = None,
                   cbformat: float = '%.1e', cbticks: list[float] | None = None,
                   cbticklabels: list[str] | None = None, cblocation: str = 'right',
-                  show_beam: bool = True, beamcolor: str = 'gray',
-                  beampos: list[float, float] | None = None,
-                  beam_kwargs: dict = {},
                   **kwargs) -> None:
-        """Use Axes.pcolormesh of matplotlib. kwargs must include the arguments of AstroData to specify the data to be plotted.
+        """Use Axes.pcolormesh of matplotlib. kwargs must include the arguments of AstroData to specify the data to be plotted. kwargs may include arguments for add_beam() and a dict of beam_kwargs to specify the beam patch in more detail.
 
         Args:
             xskip, yskip (int, optional): Spatial pixel skip. Defaults to 1.
@@ -665,12 +685,9 @@ class PlotAstroData(AstroFrame):
             cbticks (list, optional): Ticks of colorbar. Defaults to None.
             cbticklabels (list, optional): Ticklabels of colorbar. Defaults to None.
             cblocation (str, optional): 'left', 'top', 'left', 'right'. Only for 2D images. Defaults to 'right'.
-            show_beam (bool, optional): Defaults to True.
-            beamcolor (str, optional): Matplotlib color. Defaults to 'gray'.
-            beampos (list, optional): Relative position. Defaults to None.
-            beam_kwargs (dict, optional): Keyword arguments for add_beam(). Defaults to {}.
         """
         _kw = {'cmap': 'cubehelix', 'alpha': 1, 'edgecolors': 'none', 'zorder': 1}
+        beam_kwargs = kwargs2beamargs(kwargs)
         _kw.update(kwargs)
         d = kwargs2AstroData(_kw)
         self.read(d, xskip, yskip)
@@ -729,27 +746,19 @@ class PlotAstroData(AstroFrame):
                     ticklin = 1 + (1 - stretchpower) * np.log(10) * t
                     ticklin = cmin_org * ticklin**(1 / (1 - stretchpower))
                 cb.set_ticklabels([f'{d:{cbformat[1:]}}' for d in ticklin])
-        if show_beam:
-            self.add_beam(beam=beam, beamcolor=beamcolor, beampos=beampos,
-                          **beam_kwargs)
+        self.add_beam(beam=beam, **beam_kwargs)
 
     def add_contour(self, xskip: int = 1, yskip: int = 1,
                     levels: list[float] = [-12, -6, -3, 3, 6, 12, 24, 48, 96, 192, 384],
-                    show_beam: bool = True, beamcolor: str = 'gray',
-                    beampos: list[float, float] | None = None,
-                    beam_kwargs: dict = {},
                     **kwargs) -> None:
-        """Use Axes.contour of matplotlib. kwargs must include the arguments of AstroData to specify the data to be plotted.
+        """Use Axes.contour of matplotlib. kwargs must include the arguments of AstroData to specify the data to be plotted. kwargs may include arguments for add_beam() and a dict of beam_kwargs to specify the beam patch in more detail.
 
         Args:
             xskip, yskip (int, optional): Spatial pixel skip. Defaults to 1.
             levels (list, optional): Contour levels in the unit of sigma. Defaults to [-12,-6,-3,3,6,12,24,48,96,192,384].
-            show_beam (bool, optional): Defaults to True.
-            beamcolor (str, optional): Matplotlib color. Defaults to 'gray'.
-            beampos (list, optional): Relative position. Defaults to None.
-            beam_kwargs (dict, optional): Keyword arguments for add_beam(). Defaults to {}.
         """
         _kw = {'colors': 'gray', 'linewidths': 1.0, 'zorder': 2}
+        beam_kwargs = kwargs2beamargs(kwargs)
         _kw.update(kwargs)
         d = kwargs2AstroData(_kw)
         self.read(d, xskip, yskip)
@@ -761,9 +770,7 @@ class PlotAstroData(AstroFrame):
             c = [c[self.channelnumber]]
         for axnow, cnow in zip(self.ax, c):
             axnow.contour(x, y, cnow, np.sort(levels) * sigma, **_kw)
-        if show_beam:
-            self.add_beam(beam=beam, beamcolor=beamcolor, beampos=beampos,
-                          **beam_kwargs)
+        self.add_beam(beam=beam, **beam_kwargs)
 
     def add_segment(self, ampfits: str = None, angfits: str = None,
                     Ufits: str = None, Qfits: str = None,
@@ -775,11 +782,8 @@ class PlotAstroData(AstroFrame):
                     ampfactor: float = 1., angonly: bool = False,
                     rotation: float = 0.,
                     cutoff: float = 3.,
-                    show_beam: bool = True, beamcolor: str = 'gray',
-                    beampos: list[float, float] | None = None,
-                    beam_kwargs: dict = {},
                     **kwargs) -> None:
-        """Use Axes.quiver of matplotlib. kwargs must include the arguments of AstroData to specify the data to be plotted. fitsimage = [ampfits, angfits, Ufits, Qfits]. data = [amp, ang, stU, stQ].
+        """Use Axes.quiver of matplotlib. kwargs must include the arguments of AstroData to specify the data to be plotted. fitsimage = [ampfits, angfits, Ufits, Qfits]. data = [amp, ang, stU, stQ]. kwargs may include arguments for add_beam() and a dict of beam_kwargs to specify the beam patch in more detail.
 
         Args:
             ampfits (str, optional): In put fits name. Length of segment. Defaults to None.
@@ -795,14 +799,11 @@ class PlotAstroData(AstroFrame):
             angonly (bool, optional): True means amp=1 for all. Defaults to False.
             rotation (float, optional): Segment angle is ang + rotation. Defaults to 0..
             cutoff (float, optional): Used when amp and ang are calculated from Stokes U and Q. In the unit of sigma. Defaults to 3..
-            show_beam (bool, optional): Defaults to True.
-            beamcolor (str, optional): Matplotlib color. Defaults to 'gray'.
-            beampos (list, optional): Relative position. Defaults to None.
-            beam_kwargs (dict, optional): Keyword arguments for add_beam(). Defaults to {}.
         """
         _kw = {'angles': 'xy', 'scale_units': 'xy', 'color': 'gray',
                'pivot': 'mid', 'headwidth': 0, 'headlength': 0,
                'headaxislength': 0, 'width': 0.007, 'zorder': 3}
+        beam_kwargs = kwargs2beamargs(kwargs)
         _kw.update(kwargs)
         _kw['data'] = [amp, ang, stU, stQ]
         _kw['fitsimage'] = [ampfits, angfits, Ufits, Qfits]
@@ -833,34 +834,25 @@ class PlotAstroData(AstroFrame):
         _kw['scale'] = 1 if len(x) == 1 else 1. / np.abs(x[1] - x[0])
         for axnow, unow, vnow in zip(self.ax, U, V):
             axnow.quiver(x, y, unow, vnow, **_kw)
-        if show_beam:
-            self.add_beam(beam=beam, beamcolor=beamcolor, beampos=beampos,
-                          **beam_kwargs)
+        self.add_beam(beam=beam, **beam_kwargs)
 
     def add_rgb(self, xskip: int = 1, yskip: int = 1,
                 stretch: list[str, str, str] = ['linear'] * 3,
                 stretchscale: list[float | None, float | None, float | None] = [None] * 3,
                 stretchpower: float = 0,
-                show_beam: bool = True,
-                beamcolor: list[str, str, str] = ['red', 'green', 'blue'],
-                beampos: list[list[float, float] | None] = [None, None, None],
-                beam_kwargs: dict = {},
                 **kwargs) -> None:
-        """Use PIL.Image and imshow of matplotlib. kwargs must include the arguments of AstroData to specify the data to be plotted. A three-element array ([red, green, blue]) is supposed for all arguments, except for xskip, yskip and show_beam, including vmax and vmin.
+        """Use PIL.Image and imshow of matplotlib. kwargs must include the arguments of AstroData to specify the data to be plotted. A three-element array ([red, green, blue]) is supposed for all arguments, except for xskip, yskip and show_beam, including vmax and vmin. kwargs may include arguments for add_beam() and a dict of beam_kwargs to specify the beam patch in more detail.
 
         Args:
             xskip, yskip (int, optional): Spatial pixel skip. Defaults to 1.
             stretch (str, optional): 'log' means the mapped data are logarithmic. 'asinh' means the mapped data are arc sin hyperbolic. 'power' means the mapped data are power-law (see also stretchpower). Defaults to 'linear'.
             stretchscale (float, optional): color scale is asinh(data / stretchscale). Defaults to None.
             stretchpower (float, optional): color scale is ((data / vmin)**(1 - stretchpower) - 1) / (1 - stretchpower) / ln(10). 0 means the linear scale. 1 means the logarithmic scale. Defaults to 0.
-            show_beam (bool, optional): Defaults to True.
-            beamcolor (list, optional): Matplotlib color. Defaults to ['red', 'green', 'blue'].
-            beampos (list, optional): Relative position. Defaults to None.
-            beam_kwargs (dict, optional): Keyword arguments for add_beam(). Defaults to {}.
         """
         from PIL import Image
 
         _kw = {}
+        beam_kwargs = kwargs2beamargs(kwargs)
         _kw.update(kwargs)
         d = kwargs2AstroData(_kw)
         self.read(d, xskip, yskip)
@@ -889,9 +881,7 @@ class PlotAstroData(AstroFrame):
                     im.putpixel((i, j), value)
             axnow.imshow(im, extent=[x[0], x[-1], y[0], y[-1]])
             axnow.set_aspect(np.abs((x[-1]-x[0]) / (y[-1]-y[0])))
-        if show_beam:
-            self.add_beam(beam=beam, beamcolor=beamcolor, beampos=beampos,
-                          **beam_kwargs)
+        self.add_beam(beam=beam, **beam_kwargs)
 
     def _set_axis_shared(self, pa2: PlotAxes2D, title: dict | str | None):
         """Internal method used in set_axis() and set_axis_radec().
